\docType{package}
\name{NlsyLinks-package}
\alias{NlsyLinks}
\alias{NlsyLinks-package}
\title{Utilities and kinship information for Behavior Genetics and Developmental research using the NLSY.}
\description{
  Utilities and kinship information for Behavior Genetics
  and Developmental research using the NLSY.
}
\note{
  This package considers both Gen1 and Gen2 subjects.
  "Gen1" refers to subjects in the original NLSY79 sample
  (\url{http://www.bls.gov/nls/nlsy79.htm}).  "Gen2"
  subjects are the biological children of the Gen1 females
  -ie, those in the NLSY79 Children and Young Adults sample
  (\url{http://www.bls.gov/nls/nlsy79ch.htm}).
}
\examples{
library(NlsyLinks) #Load the package into the current R session.
summary(Links79Pair)  #Summarize the five variables.
hist(Links79Pair$R)  #Display a histogram of the Relatedness values.
table(Links79Pair$R)  #Create a table of the Relatedness values for the whole sample.
}
\author{
  \href{http://scholar.google.com/citations?user=ffsJTC0AAAAJ}{William
  Howard Beasley} (\href{http://howardliveoak.com/}{Howard
  Live Oak LLC}, Norman)

  \href{http://www.vanderbilt.edu/psychological_sciences/bio/joe-rodgers}{Joseph
  Lee Rodgers} (Vanderbilt University, Nashville)

  \href{http://find.ouhsc.edu/Faculty.aspx?FacultyID=1041}{David
  Bard} (University of Oklahoma Health Sciences Center,
  OKC)

  Kelly Meredith (Oklahoma City University, OKC)

  \href{http://students.ou.edu/H/Michael.D.Hunter-1/}{Michael
  D. Hunter} (University of Oklahoma, Norman)

  Maintainer: Will Beasley <wibeasley@hotmail.com>
}
\references{
  This package's development was largely supported by the
  NIH Grant 1R01HD65865,
  \href{http://taggs.hhs.gov/AwardDetail.cfm?s_Award_Num=R01HD065865&n_Prog_Office_Code=50}{``NLSY
  Kinship Links: Reliable and Valid Sibling
  Identification"} (PI: Joe Rodgers).  A more complete list
  of research articles using NLSY Kinship Links is
  maintained on our
  \href{https://github.com/LiveOak/NlsyLinksDetermination/wiki/Articles}{repository's
  wiki}.

  Rodgers, Joseph Lee, & Kohler, Hans-Peter (2005).
  \href{http://www.springerlink.com/content/n3x1v1q282583366/}{Reformulating
  and simplifying the DF analysis model.} \emph{Behavior
  Genetics, 35} (2), 211-217.

  Rodgers, J.L., Bard, D., Johnson, A., D'Onofrio, B., &
  Miller, W.B. (2008).
  \href{http://www.ncbi.nlm.nih.gov/pubmed/18825497}{The
  Cross-Generational Mother-Daughter-Aunt-Niece Design:
  Establishing Validity of the MDAN Design with NLSY
  Fertility Variables.} \emph{Behavior Genetics, 38},
  567-578.

  D'Onofrio, B.M., Van Hulle, C.A., Waldman, I.D., Rodgers,
  J.L., Rathouz, P.J., & Lahey, B.B. (2007).
  \href{http://www.ncbi.nlm.nih.gov/pubmed/17984398}{Causal
  inferences regarding prenatal alcohol exposure and
  childhood externalizing problems.} \emph{Archives of
  General Psychiatry, 64}, 1296-1304.

  Rodgers, J.L. & Doughty, D. (2000).
  \href{http://link.springer.com/chapter/10.1007\%2F978-1-4615-4467-8_6}{Genetic
  and environmental influences on fertility expectations
  and outcomes using NLSY kinship data.} In J.L. Rodgers,
  D. Rowe, & W.B. Miller (Eds.) \emph{Genetic influences on
  fertility and sexuality.} Boston: Kluwer Academic Press.

  Cleveland, H.H., Wiebe, R.P., van den Oord, E.J.C.G., &
  Rowe, D.C. (2000).
  \href{http://www.ncbi.nlm.nih.gov/pubmed/10953940}{Behavior
  problems among children from different family structures:
  The influence of genetic self-selection.} \emph{Child
  Development, 71}, 733-751.

  Rodgers, J.L., Rowe, D.C., & Buster, M. (1999).
  \href{http://www.ncbi.nlm.nih.gov/pubmed/10081235}{Nature,
  nurture, and first sexual intercourse in the USA: Fitting
  behavioural genetic models to NLSY kinship data.}
  \emph{Journal of Biosocial Sciences, 31}.

  Rodgers, J.L., Rowe, D.C., & Li, C. (1994).
  \href{http://psycnet.apa.org/journals/dev/30/3/374/}{Beyond
  nature versus nurture: DF analysis of nonshared
  influences on problem behaviors.} \emph{Developmental
  Psychology, 30}, 374-384.
}
\keyword{package}

